"use strict";
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const eui_1 = require("@elastic/eui");
const react_1 = tslib_1.__importDefault(require("react"));
const link_to_1 = require("../../pages/link_to");
exports.NodeContextMenu = ({ options, timeRange, children, node, isPopoverOpen, closePopover, nodeType, }) => {
    const nodeName = node.path.length > 0 ? node.path[node.path.length - 1].value : undefined;
    const nodeLogsUrl = nodeName
        ? link_to_1.getNodeLogsUrl({
            nodeType,
            nodeName,
            time: timeRange.to,
        })
        : undefined;
    const nodeDetailUrl = nodeName
        ? link_to_1.getNodeDetailUrl({
            nodeType,
            nodeName,
            from: timeRange.from,
            to: timeRange.to,
        })
        : undefined;
    const panels = [
        {
            id: 0,
            title: '',
            items: [
                ...(nodeLogsUrl
                    ? [
                        {
                            name: `View logs`,
                            href: nodeLogsUrl,
                        },
                    ]
                    : []),
                ...(nodeDetailUrl
                    ? [
                        {
                            name: `View metrics`,
                            href: nodeDetailUrl,
                        },
                    ]
                    : []),
            ],
        },
    ];
    return (react_1.default.createElement(eui_1.EuiPopover, { closePopover: closePopover, id: `${node.id}-popover`, isOpen: isPopoverOpen, button: children, panelPaddingSize: "none" },
        react_1.default.createElement(eui_1.EuiContextMenu, { initialPanelId: 0, panels: panels })));
};
