"use strict";
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
const react_1 = tslib_1.__importDefault(require("react"));
const react_apollo_1 = require("react-apollo");
const capabilities_gql_query_1 = require("./capabilities.gql_query");
exports.WithCapabilities = ({ children, layouts, nodeType, nodeId, sourceId, }) => {
    return (react_1.default.createElement(react_apollo_1.Query, { query: capabilities_gql_query_1.capabilitiesQuery, fetchPolicy: "no-cache", variables: {
            sourceId,
            nodeType,
            nodeId,
        } }, ({ data, error, loading }) => {
        const capabilities = data && data.source && data.source.capabilitiesByNode;
        const filteredLayouts = getFilteredLayouts(layouts, capabilities);
        return children({
            filteredLayouts,
            error: error && error.message,
            loading,
        });
    }));
};
const getFilteredLayouts = (layouts, capabilities) => {
    if (!capabilities) {
        return layouts;
    }
    const metricCapabilities = capabilities
        .filter(cap => cap && cap.source === 'metrics')
        .map(cap => cap && cap.name);
    // After filtering out sections that can't be displayed, a layout may end up empty and can be removed.
    const filteredLayouts = layouts
        .map(layout => getFilteredLayout(layout, metricCapabilities))
        .filter(layout => layout.sections.length > 0);
    return filteredLayouts;
};
const getFilteredLayout = (layout, metricCapabilities) => {
    // A section is only displayed if at least one of its requirements is met
    // All others are filtered out.
    const filteredSections = layout.sections.filter(section => lodash_1.default.intersection(section.requires, metricCapabilities).length > 0);
    return { ...layout, sections: filteredSections };
};
