"use strict";
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
class InfraSourceStatus {
    constructor(adapter, libs) {
        this.adapter = adapter;
        this.libs = libs;
    }
    async getLogIndexNames(request, sourceId) {
        const sourceConfiguration = await this.libs.sources.getConfiguration(sourceId);
        const indexNames = await this.adapter.getIndexNames(request, sourceConfiguration.logAlias);
        return indexNames;
    }
    async getMetricIndexNames(request, sourceId) {
        const sourceConfiguration = await this.libs.sources.getConfiguration(sourceId);
        const indexNames = await this.adapter.getIndexNames(request, sourceConfiguration.metricAlias);
        return indexNames;
    }
    async hasLogAlias(request, sourceId) {
        const sourceConfiguration = await this.libs.sources.getConfiguration(sourceId);
        const hasAlias = await this.adapter.hasAlias(request, sourceConfiguration.logAlias);
        return hasAlias;
    }
    async hasMetricAlias(request, sourceId) {
        const sourceConfiguration = await this.libs.sources.getConfiguration(sourceId);
        const hasAlias = await this.adapter.hasAlias(request, sourceConfiguration.metricAlias);
        return hasAlias;
    }
    async hasLogIndices(request, sourceId) {
        const sourceConfiguration = await this.libs.sources.getConfiguration(sourceId);
        const hasIndices = await this.adapter.hasIndices(request, sourceConfiguration.logAlias);
        return hasIndices;
    }
    async hasMetricIndices(request, sourceId) {
        const sourceConfiguration = await this.libs.sources.getConfiguration(sourceId);
        const hasIndices = await this.adapter.hasIndices(request, sourceConfiguration.metricAlias);
        return hasIndices;
    }
}
exports.InfraSourceStatus = InfraSourceStatus;
