"use strict";
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const operators_1 = require("rxjs/operators");
const discovery_1 = require("./discovery");
const plugins_config_1 = require("./plugins_config");
class PluginsService {
    constructor(env, logger, configService) {
        this.env = env;
        this.logger = logger;
        this.configService = configService;
        this.log = logger.get('plugins', 'service');
    }
    async start() {
        this.log.debug('starting plugins service');
        // At this stage we report only errors that can occur when new platform plugin
        // manifest is present, otherwise we can't be sure that the plugin is for the new
        // platform and let legacy platform to handle it.
        const errorTypesToReport = [
            discovery_1.PluginDiscoveryErrorType.IncompatibleVersion,
            discovery_1.PluginDiscoveryErrorType.InvalidManifest,
        ];
        const { error$, plugin$ } = await this.configService
            .atPath('plugins', plugins_config_1.PluginsConfig)
            .pipe(operators_1.first(), operators_1.map(config => discovery_1.discover(config, this.env.packageInfo, this.logger.get('plugins', 'discovery'))))
            .toPromise();
        await error$
            .pipe(operators_1.filter(error => errorTypesToReport.includes(error.type)), operators_1.tap(invalidManifestError => this.log.error(invalidManifestError)))
            .toPromise();
        await plugin$
            .pipe(operators_1.toArray(), operators_1.tap(plugins => this.log.debug(`Discovered ${plugins.length} plugins.`)))
            .toPromise();
    }
    async stop() {
        this.log.debug('stopping plugins service');
    }
}
exports.PluginsService = PluginsService;
